<?php

namespace Litecms\ButtonSettings\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Litecms\ButtonSettings\Http\Requests\ButtonSettingsRequest;
use Litecms\ButtonSettings\Interfaces\ButtonSettingsRepositoryInterface;
use Litecms\ButtonSettings\Models\ButtonSettings;

/**
 * Resource controller class for button_settings.
 */
class ButtonSettingsResourceController extends BaseController
{

    /**
     * Initialize button_settings resource controller.
     *
     * @param type ButtonSettingsRepositoryInterface $button_settings
     *
     * @return null
     */
    public function __construct(ButtonSettingsRepositoryInterface $button_settings)
    {
        parent::__construct();
        $this->repository = $button_settings;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Litecms\ButtonSettings\Repositories\Criteria\ButtonSettingsResourceCriteria::class);
    }

    /**
     * Display a list of button_settings.
     *
     * @return Response
     */
    public function index(ButtonSettingsRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Litecms\ButtonSettings\Repositories\Presenter\ButtonSettingsPresenter::class)
                ->$function();
        }

        $button_settings = $this->repository->paginate();

        return $this->response->title(trans('button_settings::button_settings.names'))
            ->view('button_settings::button_settings.index', true)
            ->data(compact('button_settings'))
            ->output();
    }

    /**
     * Display button_settings.
     *
     * @param Request $request
     * @param Model   $button_settings
     *
     * @return Response
     */
    public function show(ButtonSettingsRequest $request, ButtonSettings $button_settings)
    {

        if ($button_settings->exists) {
            $view = 'button_settings::button_settings.show';
        } else {
            $view = 'button_settings::button_settings.new';
        }

        return $this->response->title(trans('app.view') . ' ' . trans('button_settings::button_settings.name'))
            ->data(compact('button_settings'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new button_settings.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(ButtonSettingsRequest $request)
    {

        $button_settings = $this->repository->newInstance([]);
        return $this->response->title(trans('app.new') . ' ' . trans('button_settings::button_settings.name')) 
            ->view('button_settings::button_settings.create', true) 
            ->data(compact('button_settings'))
            ->output();
    }

    /**
     * Create new button_settings.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(ButtonSettingsRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $button_settings                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('button_settings::button_settings.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('button_settings/button_settings/' . $button_settings->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/button_settings/button_settings'))
                ->redirect();
        }

    }

    /**
     * Show button_settings for editing.
     *
     * @param Request $request
     * @param Model   $button_settings
     *
     * @return Response
     */
    public function edit(ButtonSettingsRequest $request, ButtonSettings $button_settings)
    {
        return $this->response->title(trans('app.edit') . ' ' . trans('button_settings::button_settings.name'))
            ->view('button_settings::button_settings.edit', true)
            ->data(compact('button_settings'))
            ->output();
    }

    /**
     * Update the button_settings.
     *
     * @param Request $request
     * @param Model   $button_settings
     *
     * @return Response
     */
    public function update(ButtonSettingsRequest $request, ButtonSettings $button_settings)
    {
        try {
            $attributes = $request->all();

            $button_settings->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('button_settings::button_settings.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('button_settings/button_settings/' . $button_settings->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('button_settings/button_settings/' . $button_settings->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the button_settings.
     *
     * @param Model   $button_settings
     *
     * @return Response
     */
    public function destroy(ButtonSettingsRequest $request, ButtonSettings $button_settings)
    {
        try {

            $button_settings->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('button_settings::button_settings.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('button_settings/button_settings/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('button_settings/button_settings/' . $button_settings->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple button_settings.
     *
     * @param Model   $button_settings
     *
     * @return Response
     */
    public function delete(ButtonSettingsRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('button_settings::button_settings.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('button_settings/button_settings'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/button_settings/button_settings'))
                ->redirect();
        }

    }

    /**
     * Restore deleted button_settings.
     *
     * @param Model   $button_settings
     *
     * @return Response
     */
    public function restore(ButtonSettingsRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('button_settings::button_settings.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/button_settings/button_settings'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/button_settings/button_settings/'))
                ->redirect();
        }

    }

}
